.. Bob documentation master file, created by
   sphinx-quickstart on Tue Dec 22 12:35:23 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Bob's documentation!
===============================

.. image:: /BOB_Logo.png
   :target: https://bobbuildtool.github.io/

To get a glimpse on Bob start with the :doc:`Tutorial <tutorial/index>` or have
a look at the `website <https://bobbuildtool.github.io/>`_. For a comprehensive
reference on Bob's usage and features have a look at the :doc:`User manual
<manual/index>`.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   tutorial/index
   manual/index
   manpages/index
   releases/index

Copyright
---------

This documentation is part of the Bob build tool, Copyright (C) 2016 TechniSat
Digital GmbH.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

